@@ -1,8 +1,9 @@
 use strict;
 use warnings;
 package App::Pastebin::Create;
-#ABSTRACT: Create and upload paste to pastebin (DOCUMENTATION IN DEVELOPMENT)
+#ABSTRACT: Simple CLI App to create and upload to Pastebin.com
 # FILE HOLDER/THIS IS COMMAND LINE APP, executable name is pastebin-create
+# The executable located in bin/
 # type pastebin -h for usage
 
 
@@ -19,7 +20,7 @@ Adapted from WWW::Pastebin::PastebinCom::Create module.
 
 =head1 VERSION
 
-version 1.0006
+version 1.0008
 
 =head1 EXAMPLE USAGE
 	
@@ -40,11 +41,13 @@ OPTIONAL
 Syntax highlighting choice, see here for list - L<https://metacpan.org/pod/WWW::Pastebin::PastebinCom::Create>
 
 =head2 --expiry, -e
-OPTIONAL
+OPTIONAL\
+
+DEFAULT TO: 30 days/1 month
 
 Your paste time to expired.
 
-Example: Never, 10m (10 minutes)
+Example: Never, 10m (10 minutes) 
 
 =head2 --private, -p
 OPTIONAL
@@ -58,7 +61,7 @@ Your paste title description.
 
 =head1 SEE ALSO
 
-L<https://metacpan.org/pod/WWW::Pastebin::PastebinCom::Create>, L< https://metacpan.org/pod/App::Nopaste>
+L<https://metacpan.org/pod/WWW::Pastebin::PastebinCom::Create>, L<https://metacpan.org/pod/App::Nopaste>
 
 
 =head1 AUTHOR
@@ -69,6 +72,7 @@ mfzz, <mfzz@cpan.org>
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2016 by mfzz.
+
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
